@@ -52,6 +52,11 @@ void setDotPath()
   Config_getString("DOT_PATH")=getResourcePath();
 }
 
+void setMscgenPath()
+{
+  Config_getString("MSCGEN_PATH")=getResourcePath();
+}
+
 #endif
 
 
@@ -216,9 +221,6 @@ Step2::Step2(QWidget *parent) : QWidget(parent,"Step2")
   layout->addWidget(m_optimizeLang);
 
   layout->addStretch(1);
-
-  connect(m_crossRef,SIGNAL(stateChanged(int)),
-          parent,SLOT(changeCrossRefState(int)));
 }
 
 bool Step2::crossReferencingEnabled() const
@@ -504,8 +506,8 @@ Step4::Step4(QWidget *parent) : QWidget(parent,"Step4")
 
   connect(m_diagramMode,SIGNAL(clicked(int)),
           this,SLOT(diagramModeChanged(int)));
-  connect(m_dotCall,SIGNAL(stateChanged(int)),
-          parent,SLOT(changeCallGraphState(int)));
+  //connect(m_dotCall,SIGNAL(stateChanged(int)),
+  //        parent,SLOT(changeCallGraphState(int)));
 }
 
 void Step4::diagramModeChanged(int buttonId)
@@ -513,15 +515,15 @@ void Step4::diagramModeChanged(int buttonId)
   m_dotOptions->setEnabled(buttonId==2);
 }
 
-void Step4::disableCallGraphs()
-{
-  m_dotCall->setChecked(FALSE);
-}
+//void Step4::disableCallGraphs()
+//{
+//  m_dotCall->setChecked(FALSE);
+//}
 
-bool Step4::callGraphEnabled() const
-{
-  return m_dotCall->isOn();
-}
+//bool Step4::callGraphEnabled() const
+//{
+//  return m_dotCall->isOn();
+//}
 
 DiagramMode Step4::diagramMode() const
 {
@@ -616,44 +618,6 @@ Wizard::Wizard(QWidget *parent=0) : QTabDialog(parent)
   setCancelButton();
 }
 
-void Wizard::changeCallGraphState(int state)
-{
-  if (state==QButton::On && !m_step2->crossReferencingEnabled())
-  {
-    if (QMessageBox::question(this,"This option depends on another option",
-                              "The call graph option requires that cross-referencing "
-                              "of source code is enabled.\nDo you want to enable this "
-                              "option?",QMessageBox::Yes,QMessageBox::No)==QMessageBox::Yes)
-    {
-      m_step2->enableCrossReferencing();
-    }
-    else
-    {
-      m_step4->disableCallGraphs();
-    }
-  }
-}
-
-void Wizard::changeCrossRefState(int state)
-{
-  if (state==QButton::Off && m_step4->callGraphEnabled())
-  {
-    if (QMessageBox::question(this,"Another option depends on this one",
-                              "The call graph option requires that cross-referencing "
-                              "of source code is enabled.\nDo you want to disable the call "
-                              "graph option?",QMessageBox::Yes,QMessageBox::No
-                             )==QMessageBox::Yes
-       )
-    {
-      m_step4->disableCallGraphs();
-    }
-    else
-    {
-      m_step2->enableCrossReferencing();
-    }
-  }
-}
-
 //==========================================================================
 
 MainWidget::MainWidget(QWidget *parent) 
@@ -667,6 +631,7 @@ MainWidget::MainWidget(QWidget *parent)
   Config_getBool("HAVE_DOT")=TRUE;
 #if defined(Q_OS_MACX)
   setDotPath();
+  setMscgenPath();
 #endif
   
   QWidget *w = new QWidget(this);
@@ -915,7 +880,7 @@ void MainWidget::launchWizard()
   {
     wizard.setHtmlStyle(HS_CHM);
   }
-  else if (Config_getBool("GENERATE_TREEVIEW"))
+  else if (Config_getEnum("GENERATE_TREEVIEW")!="NONE")
   {
     wizard.setHtmlStyle(HS_TreeView);
   }
@@ -1043,15 +1008,15 @@ void MainWidget::launchWizard()
       {
         case HS_Plain:
           Config_getBool("GENERATE_HTMLHELP")=FALSE;
-          Config_getBool("GENERATE_TREEVIEW")=FALSE;
+          Config_getEnum("GENERATE_TREEVIEW")="NONE";
           break;
         case HS_TreeView:
           Config_getBool("GENERATE_HTMLHELP")=FALSE;
-          Config_getBool("GENERATE_TREEVIEW")=TRUE;
+          Config_getEnum("GENERATE_TREEVIEW")="ALL";
           break;
         case HS_CHM:
           Config_getBool("GENERATE_HTMLHELP")=TRUE;
-          Config_getBool("GENERATE_TREEVIEW")=FALSE;
+          Config_getEnum("GENERATE_TREEVIEW")="NONE";
           break;
       }
     }
@@ -1097,10 +1062,14 @@ void MainWidget::launchWizard()
         break;
     }
 #if defined(Q_OS_MACX)
-    if (Config_getBool("HAVE_DOT"))
+    if (Config_getString("DOT_PATH").isEmpty())
     {
       setDotPath();
     }
+    if (Config_getString("MSCGEN_PATH").isEmpty())
+    {
+      setMscgenPath();
+    }
 #endif
     setConfigSaved(FALSE);
   }
@@ -1136,6 +1105,18 @@ void MainWidget::loadConfigFromFile(const QString &fn)
     addRecentFile(fn);
     m_workingDir->setText(QFileInfo(fn).dirPath(TRUE));
     m_configFileName = fn;
+#if defined(Q_OS_MACX)
+    if (Config_getString("DOT_PATH").isEmpty())
+    {
+      setDotPath();
+      setConfigSaved(FALSE);
+    }
+    if (Config_getString("MSCGEN_PATH").isEmpty())
+    {
+      setMscgenPath();
+      setConfigSaved(FALSE);
+    }
+#endif
     statusBar()->message("New configuration loaded",messageTimeout);
   }
 }
@@ -1222,6 +1203,7 @@ void MainWidget::resetConfig()
     Config::instance()->init();
 #if defined(Q_OS_MACX)
     setDotPath();
+    setMscgenPath();
 #endif
 
     m_configFileName = "";
@@ -1316,7 +1298,7 @@ void MainWidget::about()
   QTextStream t(&msg,IO_WriteOnly);
   t << QString("<qt><center>A tool to configure and run doxygen version ")+versionString+
        " on your source files.</center><p><br>"
-       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2006</center><p>"
+       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2008</center><p>"
        "</qt>";
   QMessageBox::about(this,"Doxygen GUI",msg);
 }
