@@ -3,7 +3,7 @@
  * $Id: def.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -457,16 +457,14 @@ void generateDEFForClass(ClassDef *cd,QTextStream &t)
   t << "  cp-documentation = <<_EnD_oF_dEf_TeXt_" << endl
     << cd->documentation() << endl << "_EnD_oF_dEf_TeXt_;" << endl;
 
-  DotClassGraph inheritanceGraph(cd,DotNode::Inheritance,
-                                 Config_getInt("MAX_DOT_GRAPH_DEPTH"));
+  DotClassGraph inheritanceGraph(cd,DotNode::Inheritance);
   if (!inheritanceGraph.isTrivial())
   {
     t << "  cp-inheritancegraph = <<_EnD_oF_dEf_TeXt_" << endl;
     inheritanceGraph.writeDEF(t);
     t << endl << "_EnD_oF_dEf_TeXt_;" << endl;
   }
-  DotClassGraph collaborationGraph(cd,DotNode::Collaboration,
-                                 Config_getInt("MAX_DOT_GRAPH_DEPTH"));
+  DotClassGraph collaborationGraph(cd,DotNode::Collaboration);
   if (!collaborationGraph.isTrivial())
   {
     t << "  cp-collaborationgraph = <<_EnD_oF_dEf_TeXt_" << endl;
@@ -481,7 +479,7 @@ void generateDEFSection(Definition *d,
     MemberList *ml,
     const char *kind)
 {
-  if (ml->count()>0)
+  if (ml && ml->count()>0)
   {
     t << "    " << kind << " = {" << endl;
     MemberListIterator mli(*ml);
