@@ -3,7 +3,7 @@
  * $Id: diagram.cpp,v 1.30 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -208,7 +208,9 @@ QCString DiagramItem::label() const
   QCString result;
   if (!templSpec.isEmpty())
   {
-    result=insertTemplateSpecifierInScope(classDef->displayName(),templSpec);
+    // we use classDef->name() here and not diplayName() in order
+    // to get the name used in the inheritance relation.
+    result=insertTemplateSpecifierInScope(classDef->name(),templSpec);
   }
   else
   {
@@ -968,7 +970,7 @@ ClassDiagram::~ClassDiagram()
 }
 
 void ClassDiagram::writeFigure(QTextStream &output,const char *path,
-                               const char *fileName)
+                               const char *fileName) const
 {
   uint baseRows=base->computeRows();
   uint superRows=super->computeRows();
@@ -1263,7 +1265,7 @@ void ClassDiagram::writeFigure(QTextStream &output,const char *path,
 
 void ClassDiagram::writeImage(QTextStream &t,const char *path,
                               const char *relPath,const char *fileName, 
-                              bool generateMap)
+                              bool generateMap) const
 {
   uint baseRows=base->computeRows();
   uint superRows=super->computeRows();
