@@ -407,6 +407,7 @@
 "	font-family: sans-serif;\n"
 "	margin:0.5em;\n"
 "}\n"
+"/* these are for tree view when used as main index */\n"
 ".directory { \n"
 "	font-size: 9pt; \n"
 "	font-weight: bold; \n"
@@ -416,6 +417,21 @@
 "	margin-top: 1em; \n"
 "	font-size: 11pt; \n"
 "}\n"
+"\n"
+"/* The following two styles can be used to replace the root node title */\n"  
+"/* with an image of your choice.  Simply uncomment the next two styles, */\n"
+"/* specify the name of your image and be sure to set \'height\' to the */\n"  
+"/* proper pixel height of your image. */\n"  
+"\n"
+"/* .directory h3.swap { */\n"
+"/* 	height: 61px; */\n"
+"/* 	background-repeat: no-repeat; */\n"
+"/* 	background-image: url(\"yourimage.gif\"); */\n"
+"/* } */\n"
+"/* .directory h3.swap span { */\n"
+"/* 	display: none; */\n"
+"/* } */\n"
+"\n"
 ".directory > h3 { \n"
 "	margin-top: 0; \n"
 "}\n"
@@ -430,4 +446,28 @@
 ".directory img { \n"
 "	vertical-align: -30%; \n"
 "}\n"
+"/* these are for tree view when not used as main index */\n"
+".directory-alt { \n"
+"	font-size: 100%; \n"
+"	font-weight: bold; \n"
+"}\n"
+".directory-alt h3 { \n"
+"	margin: 0px; \n"
+"	margin-top: 1em; \n"
+"	font-size: 11pt; \n"
+"}\n"
+".directory-alt > h3 { \n"
+"	margin-top: 0; \n"
+"}\n"
+".directory-alt p { \n"
+"	margin: 0px; \n"
+"	white-space: nowrap; \n"
+"}\n"
+".directory-alt div { \n"
+"	display: none; \n"
+"	margin: 0px; \n"
+"}\n"
+".directory-alt img { \n"
+"	vertical-align: -30%; \n"
+"}\n"
 "\n"
