@@ -662,7 +662,7 @@ void FileDef::writeSource(OutputList &ol)
     startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,TRUE);
     getDirDef()->writeNavigationPath(ol);
     ol.endQuickIndices();
-    ol.endContents();
+    ol.startContents();
     startTitle(ol,getOutputFileBase());
     ol.parseText(name());
     endTitle(ol,getOutputFileBase(),title);
@@ -1449,3 +1449,10 @@ void FileDef::writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,co
   MemberList * ml = getMemberList(lt);
   if (ml) ml->writeDocumentation(ol,name(),this,title);
 }
+
+bool FileDef::isLinkableInProject() const
+{
+  static bool showFiles = Config_getBool("SHOW_FILES");
+  return hasDocumentation() && !isReference() && showFiles;
+}
+
