@@ -2,7 +2,7 @@
  *
  * $Id: filedef.h,v 1.32 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -116,10 +116,7 @@ class FileDef : public Definition
     /*! Returns version of this file. */
     QCString getVersion() const { return fileVersion; }
     
-    bool isLinkableInProject() const
-    {
-      return hasDocumentation() && !isReference();
-    }
+    bool isLinkableInProject() const;
 
     bool isLinkable() const
     {
