@@ -166,7 +166,10 @@ void FormulaList::generateBitmaps(const char *path)
       }
       // scale the image so that it is four times larger than needed.
       // and the sizes are a multiple of four.
-      const double scaleFactor = 16.0/3.0; 
+      double scaleFactor = 16.0/3.0; 
+      int zoomFactor = Config_getInt("FORMULA_FONTSIZE");
+      if (zoomFactor<8 || zoomFactor>50) zoomFactor=10;
+      scaleFactor *= zoomFactor/10.0;
       int gx = (((int)((x2-x1)*scaleFactor))+3)&~2;
       int gy = (((int)((y2-y1)*scaleFactor))+3)&~2;
       // Then we run ghostscript to convert the postscript to a pixmap
