@@ -2,7 +2,7 @@
  *
  * $Id: groupdef.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,6 +34,7 @@
 #include "docparser.h"
 #include "searchindex.h"
 #include "dot.h"
+#include "vhdldocgen.h"
 
 GroupDef::GroupDef(const char *df,int dl,const char *na,const char *t,
                    const char *refFileName) : Definition(df,dl,na)
@@ -59,24 +60,6 @@ GroupDef::GroupDef(const char *df,int dl,const char *na,const char *t,
   memberGroupSDict->setAutoDelete(TRUE);
 
   allMemberList = new MemberList(MemberList::allMembersList);
-#if 0
-
-  decDefineMembers.setInGroup(TRUE);
-  decProtoMembers.setInGroup(TRUE);
-  decTypedefMembers.setInGroup(TRUE);
-  decEnumMembers.setInGroup(TRUE);
-  decEnumValMembers.setInGroup(TRUE);
-  decFuncMembers.setInGroup(TRUE);
-  decVarMembers.setInGroup(TRUE);
-
-  docDefineMembers.setInGroup(TRUE);
-  docProtoMembers.setInGroup(TRUE);
-  docTypedefMembers.setInGroup(TRUE);
-  docEnumMembers.setInGroup(TRUE);
-  docEnumValMembers.setInGroup(TRUE);
-  docFuncMembers.setInGroup(TRUE);
-  docVarMembers.setInGroup(TRUE);
-#endif
 
   visited = 0;
   groupScope = 0;
@@ -141,42 +124,48 @@ void GroupDef::findSectionsInDocumentation()
       ml->findSectionsInDocumentation();
     }
   }
-#if 0
-  decDefineMembers.findSectionsInDocumentation();
-  decProtoMembers.findSectionsInDocumentation();
-  decTypedefMembers.findSectionsInDocumentation();
-  decEnumMembers.findSectionsInDocumentation();
-  decFuncMembers.findSectionsInDocumentation();
-  decVarMembers.findSectionsInDocumentation();
-#endif
 }
 
 void GroupDef::addFile(const FileDef *def)
 {
+  if (def->isHidden()) return;
   if (Config_getBool("SORT_BRIEF_DOCS"))
     fileList->inSort(def);
   else
     fileList->append(def);
 }
 
-void GroupDef::addClass(const ClassDef *cd)
+bool GroupDef::addClass(const ClassDef *cd)
 {
-  if (Config_getBool("SORT_BRIEF_DOCS"))
-    classSDict->inSort(cd->name(),cd);
-  else
-    classSDict->append(cd->name(),cd);
+  if (cd->isHidden()) return FALSE;
+  if (classSDict->find(cd->name())==0)
+  {
+    if (Config_getBool("SORT_BRIEF_DOCS"))
+      classSDict->inSort(cd->name(),cd);
+    else
+      classSDict->append(cd->name(),cd);
+    return TRUE;
+  }
+  return FALSE;
 }
 
-void GroupDef::addNamespace(const NamespaceDef *def)
+bool GroupDef::addNamespace(const NamespaceDef *def)
 {
-  if (Config_getBool("SORT_BRIEF_DOCS"))
-    namespaceSDict->inSort(def->name(),def);  
-  else
-    namespaceSDict->append(def->name(),def);
+  if (def->isHidden()) return FALSE;
+  if (namespaceSDict->find(def->name())==0)
+  {
+    if (Config_getBool("SORT_BRIEF_DOCS"))
+      namespaceSDict->inSort(def->name(),def);  
+    else
+      namespaceSDict->append(def->name(),def);
+    return TRUE;
+  }
+  return FALSE;
 }
 
 void GroupDef::addDir(const DirDef *def)
 {
+  if (def->isHidden()) return;
   if (Config_getBool("SORT_BRIEF_DOCS"))
     dirList->inSort(def);  
   else
@@ -185,6 +174,7 @@ void GroupDef::addDir(const DirDef *def)
 
 void GroupDef::addPage(PageDef *def)
 {
+  if (def->isHidden()) return;
   //printf("Making page %s part of a group\n",def->name.data());
   pageDict->append(def->name(),def);
   def->makePartOfGroup(this);
@@ -192,6 +182,7 @@ void GroupDef::addPage(PageDef *def)
 
 void GroupDef::addExample(const PageDef *def)
 {
+  if (def->isHidden()) return;
   exampleDict->append(def->name(),def);
 }
 
@@ -207,15 +198,6 @@ void GroupDef::addMembersToMemberGroup()
       ::addMembersToMemberGroup(ml,&memberGroupSDict,this);
     }
   }
-#if 0
-  ::addMembersToMemberGroup(&decDefineMembers,&memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decProtoMembers,&memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decTypedefMembers,&memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decEnumMembers,&memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decEnumValMembers,&memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decFuncMembers,&memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decVarMembers,&memberGroupSDict,this);
-#endif
 
   //printf("GroupDef::addMembersToMemberGroup() memberGroupList=%d\n",memberGroupList->count());
   MemberGroupSDict::Iterator mgli(*memberGroupSDict);
@@ -229,6 +211,7 @@ void GroupDef::addMembersToMemberGroup()
 
 bool GroupDef::insertMember(MemberDef *md,bool docOnly)
 {
+  if (md->isHidden()) return FALSE;
   //printf("GroupDef(%s)::insertMember(%s)\n", title.data(), md->name().data());
   MemberNameInfo *mni=0;
   if ((mni=(*allMemberNameInfoSDict)[md->name()]))
@@ -283,107 +266,104 @@ bool GroupDef::insertMember(MemberDef *md,bool docOnly)
       if (!docOnly)
       {
         addMemberToList(MemberList::decVarMembers,md);
-        //if (Config_getBool("SORT_BRIEF_DOCS"))
-        //  decVarMembers.inSort(md);
-        //else
-        //  decVarMembers.append(md);
       }
       addMemberToList(MemberList::docVarMembers,md);
-      //if (Config_getBool("SORT_MEMBER_DOCS"))
-      //  docVarMembers.inSort(md); 
-      //else
-      //  docVarMembers.append(md);
       break;
     case MemberDef::Function: 
       if (!docOnly)
       {
         addMemberToList(MemberList::decFuncMembers,md);
-        //if (Config_getBool("SORT_BRIEF_DOCS"))
-        //  decFuncMembers.inSort(md);
-        //else
-        //  decFuncMembers.append(md);
       }
       addMemberToList(MemberList::docFuncMembers,md);
-      //if (Config_getBool("SORT_MEMBER_DOCS"))    
-      //  docFuncMembers.inSort(md); 
-      //else
-      //  docFuncMembers.append(md);
       break;
     case MemberDef::Typedef:      
       if (!docOnly)
       {
         addMemberToList(MemberList::decTypedefMembers,md);
-        //if (Config_getBool("SORT_BRIEF_DOCS"))
-        //  decTypedefMembers.inSort(md);
-        //else
-        //  decTypedefMembers.append(md);
       }
       addMemberToList(MemberList::docTypedefMembers,md);
-      //if (Config_getBool("SORT_MEMBER_DOCS"))
-      //  docTypedefMembers.inSort(md); 
-      //else
-      //  docTypedefMembers.append(md);
       break;
     case MemberDef::Enumeration:  
       if (!docOnly)
       {
         addMemberToList(MemberList::decEnumMembers,md);
-        //if (Config_getBool("SORT_BRIEF_DOCS"))
-        //  decEnumMembers.inSort(md);
-        //else
-        //  decEnumMembers.append(md);
       }
       addMemberToList(MemberList::docEnumMembers,md);
-      //if (Config_getBool("SORT_MEMBER_DOCS"))
-      //  docEnumMembers.inSort(md); 
-      //else
-      //  docEnumMembers.append(md);
       break;
     case MemberDef::EnumValue:    
       if (!docOnly)
       {
         addMemberToList(MemberList::decEnumValMembers,md);
-        //printf("enum value %s!\n",md->name().data());
-        //if (Config_getBool("SORT_BRIEF_DOCS"))
-        //  decEnumValMembers.inSort(md);
-        //else
-        //  decEnumValMembers.append(md);
       }
       addMemberToList(MemberList::docEnumValMembers,md);
-      //if (Config_getBool("SORT_MEMBER_DOCS"))
-      //  docEnumValMembers.inSort(md); 
-      //else
-      //  docEnumValMembers.append(md);
       break;
     case MemberDef::Prototype:    
       if (!docOnly)
       {
         addMemberToList(MemberList::decProtoMembers,md);
-        //if (Config_getBool("SORT_BRIEF_DOCS"))
-        //  decProtoMembers.inSort(md);
-        //else
-        //  decProtoMembers.append(md);
       }
       addMemberToList(MemberList::docProtoMembers,md);
-      //if (Config_getBool("SORT_MEMBER_DOCS"))
-      //  docProtoMembers.inSort(md); 
-      //else
-      //  docProtoMembers.append(md);
       break;
     case MemberDef::Define:       
       if (!docOnly)
       {
         addMemberToList(MemberList::decDefineMembers,md);
-        //if (Config_getBool("SORT_BRIEF_DOCS"))
-        //  decDefineMembers.inSort(md);
-        //else
-        //  decDefineMembers.append(md);
       }
       addMemberToList(MemberList::docDefineMembers,md);
-      //if (Config_getBool("SORT_MEMBER_DOCS"))
-      //  docDefineMembers.inSort(md); 
-      //else
-      //  docDefineMembers.append(md);
+      break;
+    case MemberDef::Signal:       
+      if (!docOnly)
+      {
+        addMemberToList(MemberList::decSignalMembers,md);
+      }
+      addMemberToList(MemberList::docSignalMembers,md);
+      break;
+    case MemberDef::Slot:       
+      if (md->protection()==Public)
+      {
+        if (!docOnly)
+        {
+          addMemberToList(MemberList::decPubSlotMembers,md);
+        }
+        addMemberToList(MemberList::docPubSlotMembers,md);
+      }
+      else if (md->protection()==Protected)
+      {
+        if (!docOnly)
+        {
+          addMemberToList(MemberList::decProSlotMembers,md);
+        }
+        addMemberToList(MemberList::docProSlotMembers,md);
+      }
+      else
+      {
+        if (!docOnly)
+        {
+          addMemberToList(MemberList::decPriSlotMembers,md);
+        }
+        addMemberToList(MemberList::docPriSlotMembers,md);
+      }
+      break;
+    case MemberDef::Event:       
+      if (!docOnly)
+      {
+        addMemberToList(MemberList::decEventMembers,md);
+      }
+      addMemberToList(MemberList::docEventMembers,md);
+      break;
+    case MemberDef::Property:       
+      if (!docOnly)
+      {
+        addMemberToList(MemberList::decPropMembers,md);
+      }
+      addMemberToList(MemberList::docPropMembers,md);
+      break;
+    case MemberDef::Friend:       
+      if (!docOnly)
+      {
+        addMemberToList(MemberList::decFriendMembers,md);
+      }
+      addMemberToList(MemberList::docFriendMembers,md);
       break;
     default:
       err("GroupDef::insertMembers(): "
@@ -448,6 +428,39 @@ void GroupDef::removeMember(MemberDef *md)
         removeMemberFromList(MemberList::decDefineMembers,md);
         removeMemberFromList(MemberList::docDefineMembers,md);
         break;
+      case MemberDef::Signal:       
+        removeMemberFromList(MemberList::decSignalMembers,md);
+        removeMemberFromList(MemberList::docSignalMembers,md);
+        break;
+      case MemberDef::Slot:       
+        if (md->protection()==Public)
+        {
+          removeMemberFromList(MemberList::decPubSlotMembers,md);
+          removeMemberFromList(MemberList::docPubSlotMembers,md);
+        }
+        else if (md->protection()==Protected)
+        {
+          removeMemberFromList(MemberList::decProSlotMembers,md);
+          removeMemberFromList(MemberList::docProSlotMembers,md);
+        }
+        else
+        {
+          removeMemberFromList(MemberList::decPriSlotMembers,md);
+          removeMemberFromList(MemberList::docPriSlotMembers,md);
+        }
+        break;
+      case MemberDef::Event:       
+        removeMemberFromList(MemberList::decEventMembers,md);
+        removeMemberFromList(MemberList::docEventMembers,md);
+        break;
+      case MemberDef::Property:       
+        removeMemberFromList(MemberList::decPropMembers,md);
+        removeMemberFromList(MemberList::docPropMembers,md);
+        break;
+      case MemberDef::Friend:       
+        removeMemberFromList(MemberList::decFriendMembers,md);
+        removeMemberFromList(MemberList::docFriendMembers,md);
+        break;
       default:
         err("GroupDef::removeMember(): unexpected member remove in file!\n");
     }
@@ -528,6 +541,8 @@ void GroupDef::writeDetailedDocumentation(OutputList &ol)
 
 void GroupDef::writeDocumentation(OutputList &ol)
 {
+  bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");  
+  bool vhdlOpt    = Config_getBool("OPTIMIZE_OUTPUT_VHDL");  
   ol.pushGeneratorState();
   startFile(ol,getOutputFileBase(),name(),title);
   startTitle(ol,getOutputFileBase());
@@ -708,21 +723,23 @@ void GroupDef::writeDocumentation(OutputList &ol)
       mg->writeDeclarations(ol,0,0,0,this);
     }
 
-    //allMemberList->writeDeclarations(ol,0,0,0,this,0,0); 
     writeMemberDeclarations(ol,MemberList::decDefineMembers,theTranslator->trDefines());
-    //decDefineMembers.writeDeclarations(ol,0,0,0,this,theTranslator->trDefines(),0);
     writeMemberDeclarations(ol,MemberList::decProtoMembers,theTranslator->trFuncProtos());
-    //decProtoMembers.writeDeclarations(ol,0,0,0,this,theTranslator->trFuncProtos(),0);
     writeMemberDeclarations(ol,MemberList::decTypedefMembers,theTranslator->trTypedefs());
-    //decTypedefMembers.writeDeclarations(ol,0,0,0,this,theTranslator->trTypedefs(),0);
     writeMemberDeclarations(ol,MemberList::decEnumMembers,theTranslator->trEnumerations());
-    //decEnumMembers.writeDeclarations(ol,0,0,0,this,theTranslator->trEnumerations(),0);
     writeMemberDeclarations(ol,MemberList::decEnumValMembers,theTranslator->trEnumerationValues());
-    //decEnumValMembers.writeDeclarations(ol,0,0,0,this,theTranslator->trEnumerationValues(),0,TRUE);
-    writeMemberDeclarations(ol,MemberList::decFuncMembers,theTranslator->trFunctions());
-    //decFuncMembers.writeDeclarations(ol,0,0,0,this,theTranslator->trFunctions(),0);
+    writeMemberDeclarations(ol,MemberList::decFuncMembers,
+                 fortranOpt ? theTranslator->trSubprograms()  : 
+                 vhdlOpt    ? VhdlDocGen::trFunctionAndProc() :
+                              theTranslator->trFunctions());
     writeMemberDeclarations(ol,MemberList::decVarMembers,theTranslator->trVariables());
-    //decVarMembers.writeDeclarations(ol,0,0,0,this,theTranslator->trVariables(),0);
+    writeMemberDeclarations(ol,MemberList::decSignalMembers,theTranslator->trSignals());
+    writeMemberDeclarations(ol,MemberList::decPubSlotMembers,theTranslator->trPublicSlots());
+    writeMemberDeclarations(ol,MemberList::decProSlotMembers,theTranslator->trProtectedSlots());
+    writeMemberDeclarations(ol,MemberList::decPriSlotMembers,theTranslator->trPrivateSlots());
+    writeMemberDeclarations(ol,MemberList::decEventMembers,theTranslator->trEvents());
+    writeMemberDeclarations(ol,MemberList::decPropMembers,theTranslator->trProperties());
+    writeMemberDeclarations(ol,MemberList::decFriendMembers,theTranslator->trFriends());
   }
   ol.endMemberSections();
 
@@ -779,38 +796,26 @@ void GroupDef::writeDocumentation(OutputList &ol)
 
 void GroupDef::writeMemberDocumentation(OutputList &ol)
 {
+  bool  fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
     ol.disable(OutputGenerator::Html);
   }
   
   writeMemberDocumentation(ol,MemberList::docDefineMembers,theTranslator->trDefineDocumentation());
-  //docDefineMembers.writeDocumentation(ol,name(),this,
-  //                           theTranslator->trDefineDocumentation());
-  
   writeMemberDocumentation(ol,MemberList::docProtoMembers,theTranslator->trFunctionPrototypeDocumentation());
-  //docProtoMembers.writeDocumentation(ol,name(),this,
-  //                           theTranslator->trFunctionPrototypeDocumentation());
-
   writeMemberDocumentation(ol,MemberList::docTypedefMembers,theTranslator->trTypedefDocumentation());
-  //docTypedefMembers.writeDocumentation(ol,name(),this,
-  //                           theTranslator->trTypedefDocumentation());
-  
   writeMemberDocumentation(ol,MemberList::docEnumMembers,theTranslator->trEnumerationTypeDocumentation());
-  //docEnumMembers.writeDocumentation(ol,name(),this,
-  //                           theTranslator->trEnumerationTypeDocumentation());
-
   writeMemberDocumentation(ol,MemberList::docEnumValMembers,theTranslator->trEnumerationValueDocumentation());
-  //docEnumValMembers.writeDocumentation(ol,name(),this,
-  //                           theTranslator->trEnumerationValueDocumentation(),TRUE);
-
-  writeMemberDocumentation(ol,MemberList::docFuncMembers,theTranslator->trFunctionDocumentation());
-  //docFuncMembers.writeDocumentation(ol,name(),this,
-  //                           theTranslator->trFunctionDocumentation());
-  
+  writeMemberDocumentation(ol,MemberList::docFuncMembers,fortranOpt?theTranslator->trSubprogramDocumentation():theTranslator->trFunctionDocumentation());
   writeMemberDocumentation(ol,MemberList::docVarMembers,theTranslator->trVariableDocumentation());
-  //docVarMembers.writeDocumentation(ol,name(),this,
-  //                           theTranslator->trVariableDocumentation());
+  writeMemberDocumentation(ol,MemberList::docSignalMembers,theTranslator->trSignals());   // todo: add trSignalDocumentation()
+  writeMemberDocumentation(ol,MemberList::docPubSlotMembers,theTranslator->trPublicSlots()); // todo: add trSlotDocumentation()
+  writeMemberDocumentation(ol,MemberList::docProSlotMembers,theTranslator->trProtectedSlots()); // todo: add trSlotDocumentation()
+  writeMemberDocumentation(ol,MemberList::docPriSlotMembers,theTranslator->trPrivateSlots()); // todo: add trSlotDocumentation()
+  writeMemberDocumentation(ol,MemberList::docEventMembers,theTranslator->trEvents());     // todo: add trEventDocumentation()
+  writeMemberDocumentation(ol,MemberList::docPropMembers,theTranslator->trProperties());  // todo: add trPropertyDocumentation()
+  writeMemberDocumentation(ol,MemberList::docFriendMembers,theTranslator->trFriends());   // todo: add trFriendDocumentation()
 
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
@@ -832,14 +837,6 @@ void GroupDef::writeMemberPages(OutputList &ol)
        ml->writeDocumentationPage(ol,name(),this);
     }
   }
-#if 0
-  docDefineMembers.writeDocumentationPage(ol,name(),this);
-  docProtoMembers.writeDocumentationPage(ol,name(),this);
-  docTypedefMembers.writeDocumentationPage(ol,name(),this);
-  docEnumMembers.writeDocumentationPage(ol,name(),this);
-  docFuncMembers.writeDocumentationPage(ol,name(),this);
-  docVarMembers.writeDocumentationPage(ol,name(),this);
-#endif
 
   ol.popGeneratorState();
 }
@@ -896,8 +893,7 @@ void addClassToGroups(Entry *root,ClassDef *cd)
     GroupDef *gd=0;
     if (!g->groupname.isEmpty() && (gd=Doxygen::groupSDict->find(g->groupname)))
     {
-      gd->addClass(cd);
-      cd->makePartOfGroup(gd);
+      if (gd->addClass(cd)) cd->makePartOfGroup(gd);
       //printf("Compound %s: in group %s\n",cd->name().data(),s->data());
     }
   }
@@ -914,8 +910,7 @@ void addNamespaceToGroups(Entry *root,NamespaceDef *nd)
     //printf("group `%s'\n",s->data());
     if (!g->groupname.isEmpty() && (gd=Doxygen::groupSDict->find(g->groupname)))
     {
-      gd->addNamespace(nd);
-      nd->makePartOfGroup(gd);
+      if (gd->addNamespace(nd)) nd->makePartOfGroup(gd);
       //printf("Namespace %s: in group %s\n",nd->name().data(),s->data());
     }
   }
@@ -1116,14 +1111,6 @@ void GroupDef::addListReferences()
       ml->addListReferences(this);
     }
   }
-#if 0
-  docDefineMembers.addListReferences(this);
-  docProtoMembers.addListReferences(this);
-  docTypedefMembers.addListReferences(this);
-  docEnumMembers.addListReferences(this);
-  docFuncMembers.addListReferences(this);
-  docVarMembers.addListReferences(this);
-#endif
 }
 
 MemberList *GroupDef::createMemberList(MemberList::ListType lt)
