@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.51 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -54,6 +54,7 @@ class HtmlGenerator : public OutputGenerator
 
     void startIndexSection(IndexSections) {}
     void endIndexSection(IndexSections) {}
+    void writePageLink(const char *,bool) {}
     void startProjectNumber();
     void endProjectNumber();
     void writeStyleInfo(int part);
@@ -173,12 +174,14 @@ class HtmlGenerator : public OutputGenerator
     void endIndent();
     void writeSynopsis() {}
     void startClassDiagram();
-    void endClassDiagram(ClassDiagram &,const char *,const char *);
+    void endClassDiagram(const ClassDiagram &,const char *,const char *);
     void startPageRef() {}
     void endPageRef(const char *,const char *) {}
-    //void startQuickIndexItem(const char *,const char *);
-    //void endQuickIndexItem();
+    void startQuickIndices();
+    void endQuickIndices();
     void writeQuickLinks(bool compact,HighlightedItem hli);
+    void startContents();
+    void endContents();
     void writeNonBreakableSpace(int);
     
     void startDescTable()
@@ -195,16 +198,16 @@ class HtmlGenerator : public OutputGenerator
     { t << "</td></tr>" << endl; }
     
     void startDotGraph();
-    void endDotGraph(DotClassGraph &g);
+    void endDotGraph(const DotClassGraph &g);
     void startInclDepGraph();
-    void endInclDepGraph(DotInclDepGraph &g);
+    void endInclDepGraph(const DotInclDepGraph &g);
     void startGroupCollaboration();
-    void endGroupCollaboration(DotGroupCollaboration &g);
+    void endGroupCollaboration(const DotGroupCollaboration &g);
     void startCallGraph();
-    void endCallGraph(DotCallGraph &g);
+    void endCallGraph(const DotCallGraph &g);
     void startDirDepGraph();
-    void endDirDepGraph(DotDirDeps &g);
-    void writeGraphicalHierarchy(DotGfxHierarchyTable &g);
+    void endDirDepGraph(const DotDirDeps &g);
+    void writeGraphicalHierarchy(const DotGfxHierarchyTable &g);
 
     void startTextBlock(bool) {}
     void endTextBlock(bool) {}
