@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.cpp,v 1.58 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -53,47 +53,6 @@
 //}
 
 
-static QCString escapeLabelName(const char *s)
-{
-  QCString result;
-  const char *p=s;
-  char c;
-  while ((c=*p++))
-  {
-    switch (c)
-    {
-      case '%': result+="\\%"; break;
-      case '|': result+="\\tt{\"|}"; break;
-      case '!': result+="\"!"; break;
-      default: result+=c;
-    }
-  }
-  return result;
-}
-
-static QCString escapeMakeIndexChars(LatexGenerator *g,QTextStream &t,const char *s)
-{
-  QCString result;
-  const char *p=s;
-  char str[2];
-  str[1]=0;
-  char c;
-  while ((c=*p++))
-  {
-    switch (c)
-    {
-      case '!': t << "\"!"; break;
-      case '"': t << "\"\""; break;
-      case '@': t << "\"@"; break;
-      case '|': t << "\\tt{\"|}"; break;
-      case '[': t << "["; break;
-      case ']': t << "]"; break;
-      default:  str[0]=c; g->docify(str); break;
-    }
-  }
-  return result;
-}
-
 
 LatexGenerator::LatexGenerator() : OutputGenerator()
 {
@@ -277,7 +236,7 @@ static void writeDefaultHeaderPart1(QTextStream &t)
     s=extraPackages.next();
   }
   t << "\\makeindex\n"
-    "\\setcounter{tocdepth}{1}\n"
+    "\\setcounter{tocdepth}{3}\n"
     "\\renewcommand{\\footrulewidth}{0.4pt}\n"
     "\\begin{document}\n";
   if (theTranslator->idLanguage()=="greek") t << "\\selectlanguage{greek}\n";
@@ -421,9 +380,7 @@ void LatexGenerator::writeHeaderFile(QFile &f)
 void LatexGenerator::writeStyleSheetFile(QFile &f)
 {
   QTextStream t(&f);
-#if QT_VERSION >= 200
-  t.setEncoding(QTextStream::Latin1);
-#endif
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   writeDefaultStyleSheetPart1(t);
   QCString &projectName = Config_getString("PROJECT_NAME");
@@ -431,12 +388,12 @@ void LatexGenerator::writeStyleSheetFile(QFile &f)
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2007";
+  //t << "Dimitri van Heesch \\copyright~1997-2008";
   writeDefaultStyleSheetPart2(t);
   t << theTranslator->trGeneratedAt( dateToString(TRUE), projectName );
   t << " doxygen";
   //t << " << theTranslator->trWrittenBy() << " ";
-  //t << "Dimitri van Heesch \\copyright~1997-2007";
+  //t << "Dimitri van Heesch \\copyright~1997-2008";
   writeDefaultStyleSheetPart3(t);
 }
 
@@ -628,6 +585,8 @@ void LatexGenerator::startIndexSection(IndexSections is)
         t << "{"; //Page Documentation}\n";
       }
       break;
+    case isPageDocumentation2:
+      break;
     case isEndIndex:
       break;
   }
@@ -649,8 +608,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
       break;
     case isMainPage:
       {
-        QCString indexName="index";
-        if (Config_getBool("GENERATE_TREEVIEW")) indexName="main";
+        QCString indexName=usingTreeIndex()?"main":"index";
         t << "}\n\\label{index}";
         if (Config_getBool("PDF_HYPERLINKS")) t << "\\hypertarget{index}{}";
         t << "\\input{" << indexName << "}\n";
@@ -817,6 +775,7 @@ void LatexGenerator::endIndexSection(IndexSections is)
     case isPageDocumentation:
       {
         t << "}\n";
+#if 0
         PageSDict::Iterator pdi(*Doxygen::pageSDict);
         PageDef *pd=pdi.toFirst();
         bool first=TRUE;
@@ -824,19 +783,35 @@ void LatexGenerator::endIndexSection(IndexSections is)
         {
           if (!pd->getGroupDef() && !pd->isReference())
           {
+             if (compactLatex) t << "\\section"; else t << "\\chapter";
+             t << "{" << pd->title();
+             t << "}\n";
+            
             if (compactLatex || first) t << "\\input" ; else t << "\\include";
             t << "{" << pd->getOutputFileBase() << "}\n";
             first=FALSE;
           }
         }
+#endif
       }
       break;
+    case isPageDocumentation2:
+      break;
     case isEndIndex:
       t << "\\printindex\n";
       t << "\\end{document}\n";
       break;
   }
 }
+
+void LatexGenerator::writePageLink(const char *name, bool first)
+{
+  bool &compactLatex = Config_getBool("COMPACT_LATEX");
+  if (compactLatex || first) t << "\\input" ; else t << "\\include";
+  t << "{" << name << "}\n";
+}
+
+
 void LatexGenerator::writeStyleInfo(int part)
 {
   switch(part)
@@ -854,14 +829,14 @@ void LatexGenerator::writeStyleInfo(int part)
       break;
     case 2:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2007";
+        //t << " Dimitri van Heesch \\copyright~1997-2008";
         t << "}]{}\n";
         writeDefaultStyleSheetPart2(t);
       }
       break;
     case 4:
       {
-        //t << " Dimitri van Heesch \\copyright~1997-2007";
+        //t << " Dimitri van Heesch \\copyright~1997-2008";
         writeDefaultStyleSheetPart3(t);
         endPlainFile();
       }
@@ -1068,9 +1043,10 @@ void LatexGenerator::endTitleHead(const char *fileName,const char *name)
   t << "}" << endl;
   if (name)
   {
-    t << "\\label{" << fileName << "}\\index{" 
-      << name << "@{";
-    escapeMakeIndexChars(this,t,name);
+    t << "\\label{" << fileName << "}\\index{";
+    escapeLabelName(name);
+    t << "@{";
+    escapeMakeIndexChars(name);
     t << "}}" << endl;
   }
   if (Config_getBool("PDF_HYPERLINKS") && fileName)
@@ -1132,23 +1108,27 @@ void LatexGenerator::endMemberHeader()
 void LatexGenerator::startMemberDoc(const char *clname,
                                     const char *memname,
                                     const char *,
-                                    const char *)
+                                    const char *title)
 { 
   if (memname && memname[0]!='@')
   {
     t << "\\index{";
     if (clname)
     {
-      t << clname << "@{";
-      docify(clname);
+      escapeLabelName(clname);
+      t << "@{";
+      escapeMakeIndexChars(clname);
       t << "}!";
     }
-    t << escapeLabelName(memname) << "@{";
-    escapeMakeIndexChars(this,t,memname);
+    escapeLabelName(memname);
+    t << "@{";
+    escapeMakeIndexChars(memname);
     t << "}}" << endl;
 
-    t << "\\index{" << escapeLabelName(memname) << "@{";
-    escapeMakeIndexChars(this,t,memname);
+    t << "\\index{";
+    escapeLabelName(memname);
+    t << "@{";
+    escapeMakeIndexChars(memname);
     t << "}";
     if (clname)
     {
@@ -1165,6 +1145,9 @@ void LatexGenerator::startMemberDoc(const char *clname,
   //  escapeMakeIndexChars(this,t,memname);
   //  t << "]";
   //}
+  t << "[";
+  escapeMakeIndexChars(title);
+  t << "]";
   t << "{\\setlength{\\rightskip}{0pt plus 5cm}";
   disableLinks=TRUE;
 }
@@ -1205,9 +1188,16 @@ void LatexGenerator::writeAnchor(const char *fName,const char *name)
 { 
   //printf("LatexGenerator::writeAnchor(%s,%s)\n",fName,name);
   t << "\\label{" << name << "}" << endl; 
-  if (fName && Config_getBool("PDF_HYPERLINKS"))
+  if (Config_getBool("PDF_HYPERLINKS"))
   {
-    t << "\\hypertarget{" << stripPath(fName) << "_" << name << "}{}" << endl;
+    if (fName)
+    {
+      t << "\\hypertarget{" << stripPath(fName) << "_" << name << "}{}" << endl;
+    }
+    else
+    {
+      t << "\\hypertarget{" << name << "}{}" << endl;
+    }
   }
 }
 
@@ -1221,13 +1211,17 @@ void LatexGenerator::addIndexItem(const char *s1,const char *s2)
 {
   if (s1)
   {
-    t << "\\index{" << escapeLabelName(s1) << "@{";
-    escapeMakeIndexChars(this,t,s1);
+    t << "\\index{";
+    escapeLabelName(s1);
+    t << "@{";
+    escapeMakeIndexChars(s1);
     t << "}";
     if (s2)
     {
-      t << "!" << escapeLabelName(s2) << "@{";
-      escapeMakeIndexChars(this,t,s2);
+      t << "!";
+      escapeLabelName(s2);
+      t << "@{";
+      escapeMakeIndexChars(s2);
       t << "}";
     }
     t << "}";
@@ -1343,7 +1337,7 @@ void LatexGenerator::startClassDiagram()
   //t << "{";
 }
 
-void LatexGenerator::endClassDiagram(ClassDiagram &d,
+void LatexGenerator::endClassDiagram(const ClassDiagram &d,
                                        const char *fileName,const char *)
 {
   d.writeFigure(t,dir,fileName);
@@ -1356,9 +1350,9 @@ void LatexGenerator::startAnonTypeScope(int indent)
   {
     t << "\\begin{tabbing}" << endl;
     t << "xx\\=xx\\=xx\\=xx\\=xx\\=xx\\=xx\\=xx\\=xx\\=\\kill" << endl;
-    //printf("LatexGenerator::startMemberItem() insideTabbing=TRUE\n");
     insideTabbing=TRUE;
   }
+  m_indent=indent;
 }
 
 void LatexGenerator::endAnonTypeScope(int indent)
@@ -1368,6 +1362,7 @@ void LatexGenerator::endAnonTypeScope(int indent)
     t << endl << "\\end{tabbing}";
     insideTabbing=FALSE;
   }
+  m_indent=indent;
 }
 
 void LatexGenerator::startMemberTemplateParams()
@@ -1401,7 +1396,7 @@ void LatexGenerator::endMemberItem()
   if (insideTabbing)
   {
     t << "\\\\";
- } 
+  } 
   templateMemberItem = FALSE;
   t << endl; 
 }
@@ -1414,7 +1409,7 @@ void LatexGenerator::startMemberDescription()
   }
   else
   {
-    for (int i=0;i<m_indent+1;i++) t << "\\>";
+    for (int i=0;i<m_indent+2;i++) t << "\\>";
     t << "{\\em ";
   }
 }
@@ -1427,18 +1422,17 @@ void LatexGenerator::endMemberDescription()
   }
   else
   {
-    t << "}\\\\";
-    m_indent=0;
+    t << "}\\\\\n";
   }
 }
 
 
 void LatexGenerator::writeNonBreakableSpace(int) 
 {
+  //printf("writeNonBreakbleSpace()\n");
   if (insideTabbing)
   {
     t << "\\>";
-    m_indent++;
   }
   else
     t << "~"; 
@@ -1497,7 +1491,7 @@ void LatexGenerator::startDotGraph()
 {
 }
 
-void LatexGenerator::endDotGraph(DotClassGraph &g) 
+void LatexGenerator::endDotGraph(const DotClassGraph &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1506,7 +1500,7 @@ void LatexGenerator::startInclDepGraph()
 {
 }
 
-void LatexGenerator::endInclDepGraph(DotInclDepGraph &g) 
+void LatexGenerator::endInclDepGraph(const DotInclDepGraph &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1515,7 +1509,7 @@ void LatexGenerator::startGroupCollaboration()
 {
 }
 
-void LatexGenerator::endGroupCollaboration(DotGroupCollaboration &g) 
+void LatexGenerator::endGroupCollaboration(const DotGroupCollaboration &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1524,7 +1518,7 @@ void LatexGenerator::startCallGraph()
 {
 }
 
-void LatexGenerator::endCallGraph(DotCallGraph &g) 
+void LatexGenerator::endCallGraph(const DotCallGraph &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1533,7 +1527,7 @@ void LatexGenerator::startDirDepGraph()
 {
 }
 
-void LatexGenerator::endDirDepGraph(DotDirDeps &g) 
+void LatexGenerator::endDirDepGraph(const DotDirDeps &g) 
 {
   g.writeGraph(t,EPS,Config_getString("LATEX_OUTPUT"),relPath);
 }
@@ -1600,6 +1594,13 @@ void LatexGenerator::endParamList()
   t << "\\end{Desc}" << endl;
 }
 
+void LatexGenerator::startParameterType(bool first,const char *key)
+{
+  if (!first)
+  {
+    t << "\\/ " << key << " ";
+  }
+}
 
 void LatexGenerator::printDoc(DocNode *n,const char *langExt)
 {
@@ -1649,5 +1650,43 @@ void LatexGenerator::endConstraintList()
   t << "\\end{Desc}" << endl;
 }
 
+void LatexGenerator::escapeLabelName(const char *s)
+{
+  const char *p=s;
+  char str[2];
+  str[1]=0;
+  char c;
+  while ((c=*p++))
+  {
+    switch (c)
+    {
+      case '%': t << "\\%";       break;
+      case '|': t << "\\tt{\"|}"; break;
+      case '!': t << "\"!";       break;
+      default:  str[0]=c; docify(str); break;
+    }
+  }
+}
+
+void LatexGenerator::escapeMakeIndexChars(const char *s)
+{
+  const char *p=s;
+  char str[2];
+  str[1]=0;
+  char c;
+  while ((c=*p++))
+  {
+    switch (c)
+    {
+      case '!': t << "\"!"; break;
+      case '"': t << "\"\""; break;
+      case '@': t << "\"@"; break;
+      case '|': t << "\\tt{\"|}"; break;
+      case '[': t << "["; break;
+      case ']': t << "]"; break;
+      default:  str[0]=c; docify(str); break;
+    }
+  }
+}
 
 
