@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.h,v 1.50 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -52,6 +52,7 @@ class LatexGenerator : public OutputGenerator
     
     void startIndexSection(IndexSections);
     void endIndexSection(IndexSections);
+    void writePageLink(const char *,bool);
     void startProjectNumber();
     void endProjectNumber() {}
     void writeStyleInfo(int part);
@@ -168,10 +169,14 @@ class LatexGenerator : public OutputGenerator
     void endIndent()         {}
     void writeSynopsis()     {}
     void startClassDiagram();
-    void endClassDiagram(ClassDiagram &,const char *,const char *);
+    void endClassDiagram(const ClassDiagram &,const char *,const char *);
     void startPageRef();
     void endPageRef(const char *,const char *);
+    void startQuickIndices() {}
+    void endQuickIndices() {}
     void writeQuickLinks(bool,HighlightedItem) {}
+    void startContents() {}
+    void endContents() {}
     void writeNonBreakableSpace(int);
     
     void startDescTable()
@@ -187,16 +192,16 @@ class LatexGenerator : public OutputGenerator
     void lastIndexPage() {}
 
     void startDotGraph();
-    void endDotGraph(DotClassGraph &);
+    void endDotGraph(const DotClassGraph &);
     void startInclDepGraph();
-    void endInclDepGraph(DotInclDepGraph &);
+    void endInclDepGraph(const DotInclDepGraph &);
     void startCallGraph();
     void startGroupCollaboration();
-    void endGroupCollaboration(DotGroupCollaboration &g);
-    void endCallGraph(DotCallGraph &);
+    void endGroupCollaboration(const DotGroupCollaboration &g);
+    void endCallGraph(const DotCallGraph &);
     void startDirDepGraph();
-    void endDirDepGraph(DotDirDeps &g);
-    void writeGraphicalHierarchy(DotGfxHierarchyTable &) {}
+    void endDirDepGraph(const DotDirDeps &g);
+    void writeGraphicalHierarchy(const DotGfxHierarchyTable &) {}
 
     void startTextBlock(bool) {}
     void endTextBlock(bool) {}
@@ -205,7 +210,7 @@ class LatexGenerator : public OutputGenerator
     void endMemberDocPrefixItem() {}
     void startMemberDocName(bool) {}
     void endMemberDocName() {}
-    void startParameterType(bool,const char *) {}
+    void startParameterType(bool,const char *);
     void endParameterType() {}
     void startParameterName(bool) {}
     void endParameterName(bool,bool,bool) {}
@@ -230,6 +235,8 @@ class LatexGenerator : public OutputGenerator
   private:
     LatexGenerator(const LatexGenerator &);
     LatexGenerator &operator=(const LatexGenerator &);
+    void escapeLabelName(const char *s);
+    void escapeMakeIndexChars(const char *s);
     int col;
     bool insideTabbing;
     bool firstDescItem;
