@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  * Authors: Dimitri van Heesch, Miguel Lobo.
  *
  * Permission to use, copy, modify, and distribute this software and its
@@ -484,16 +484,24 @@ void PerlModDocVisitor::closeSubBlock()
 
 void PerlModDocVisitor::openOther()
 {
+  // Using a secondary text stream will corrupt the perl file. Instead of
+  // printing doc => [ data => [] ], it will print doc => [] data => [].
+  /*
   leaveText();
   m_output.openSave();
+  */
 }
 
 void PerlModDocVisitor::closeOther()
 {
+  // Using a secondary text stream will corrupt the perl file. Instead of
+  // printing doc => [ data => [] ], it will print doc => [] data => [].
+  /*
   QString other;
   leaveText();
   m_output.closeSave(other);
   m_other += other;
+  */
 }
 
 void PerlModDocVisitor::visit(DocWord *w)
@@ -538,7 +546,7 @@ void PerlModDocVisitor::visit(DocSymbol *sy)
   case DocSymbol::Rdquo:   c = '"'; break;
   case DocSymbol::Ndash:   c = '-'; break;
   case DocSymbol::Mdash:   s = "--"; break;
-  case DocSymbol::Nbsp:    c = ''; break;
+  case DocSymbol::Nbsp:    c = ' '; break;
   case DocSymbol::Uml:     accent = "umlaut"; break;
   case DocSymbol::Acute:   accent = "acute"; break;
   case DocSymbol::Grave:   accent = "grave"; break;
@@ -1153,6 +1161,7 @@ void PerlModDocVisitor::visitPre(DocParamSect *s)
   case DocParamSect::Param:     type = "params"; break;
   case DocParamSect::RetVal:    type = "retvals"; break;
   case DocParamSect::Exception: type = "exceptions"; break;
+  case DocParamSect::TemplateParam: type = "templateparam"; break;
   case DocParamSect::Unknown:
     err("Error: unknown parameter section found\n");
     break;
@@ -1414,7 +1423,7 @@ void PerlModGenerator::generatePerlModForMember(MemberDef *md,Definition *)
   switch (md->memberType())
   {
   case MemberDef::Define:      memType="define";    break;
-  case MemberDef::EnumValue:   ASSERT(0);           break;
+  case MemberDef::EnumValue:   memType="enumvalue"; break;
   case MemberDef::Property:    memType="property";  break;
   case MemberDef::Variable:    memType="variable";  break;
   case MemberDef::Typedef:     memType="typedef";   break;
