@@ -22,7 +22,9 @@ extern char **environ;
 #endif
 
 #include "portable.h"
-//#include "debug.h"
+#ifndef NODEBUG
+#include "debug.h"
+#endif
 //#include "doxygen.h"
 
 static double  sysElapsedTime;
@@ -43,7 +45,9 @@ int  portable_system(const char *command,const char *args,bool commandHasConsole
   }
   fullCmd += " ";
   fullCmd += args;
-  //Debug::print(Debug::ExtCmd,0,"Executing external command `%s`\n",fullCmd.data());
+#ifndef NODEBUG
+  Debug::print(Debug::ExtCmd,0,"Executing external command `%s`\n",fullCmd.data());
+#endif
 
 #if !defined(_WIN32) || defined(__CYGWIN__)
   commandHasConsole=commandHasConsole;
@@ -373,7 +377,12 @@ void * portable_iconv_open(const char* tocode, const char* fromcode)
 size_t portable_iconv (void *cd, const char** inbuf,  size_t *inbytesleft, 
                                        char** outbuf, size_t *outbytesleft)
 {
-#if ((defined(_LIBICONV_VERSION) && (_LIBICONV_VERSION>=0x0109)) || defined(_OS_SOLARIS_))
+// libiconv is a mess. For some platforms/version the prototype of inbuf is
+// "const char **", for others it is "char **". C++ requires the proper cast to
+// avoid a compile error, that is were the CASTNEEDED is for.
+#if ((defined(_LIBICONV_VERSION) && (_LIBICONV_VERSION>=0x0109) && \
+      !((defined(_OS_MAC_) || defined(Q_OS_MACX) )&& (_LIBICONV_VERSION==0x010B))) \
+    || defined(_OS_SOLARIS_))
 #define CASTNEEDED(x) (x)
 #else
 #define CASTNEEDED(x) (char **)(x)
