@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -475,8 +475,8 @@ class TranslatorChinese : public Translator
         case ClassDef::Struct: result+="ṹ"; break;
         case ClassDef::Union:  result+=""; break;
         case ClassDef::Interface:  result+="ӿ"; break;
-        case ClassDef::Protocol:   result+="Э"; break; // translate me!
-        case ClassDef::Category:   result+=""; break; // translate me!
+        case ClassDef::Protocol:   result+="Э"; break;
+        case ClassDef::Category:   result+=""; break;
         case ClassDef::Exception:  result+="쳣"; break;
       }
       result+="ο";
@@ -642,8 +642,8 @@ class TranslatorChinese : public Translator
         case ClassDef::Struct:     result+="ṹ"; break;
         case ClassDef::Union:      result+=""; break;
         case ClassDef::Interface:  result+="ӿ"; break;
-        case ClassDef::Protocol:   result+="Э"; break; // translate me!
-        case ClassDef::Category:   result+=""; break; // translate me!
+        case ClassDef::Protocol:   result+="Э"; break;
+        case ClassDef::Category:   result+=""; break;
         case ClassDef::Exception:  result+="쳣"; break;
       }
       result+="ĵļɣ";
@@ -1535,7 +1535,258 @@ class TranslatorChinese : public Translator
       return "öٱĵ";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.5.4 (mainly for Fortran)
+//////////////////////////////////////////////////////////////////////////
+    
+    /*! header that is put before the list of member subprograms (Fortran). */
+    virtual QCString trMemberFunctionDocumentationFortran()
+    // { return "Member Function/Subroutine Documentation"; }
+    { return "Աĵ"; }
 
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    virtual QCString trCompoundListFortran()
+    // { return "Data Types List"; }
+    { return "б"; }
+
+    /*! This is put above each page as a link to all members of compounds (Fortran). */
+    virtual QCString trCompoundMembersFortran()
+    // { return "Data Fields"; }
+    { return ""; }
+
+    /*! This is an introduction to the annotated compound list (Fortran). */
+    virtual QCString trCompoundListDescriptionFortran()
+    // { return "Here are the data types with brief descriptions:"; }
+    { return "Ҫб:"; }
+
+    /*! This is an introduction to the page with all data types (Fortran). */
+    virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
+    {
+    //   QCString result="Here is a list of all ";
+    //   if (!extractAll)
+    //   {
+    //     result+="documented ";
+    //   }
+    //   result+="data types members";
+    //   result+=" with links to ";
+    //   if (!extractAll) 
+    //   {
+    //      result+="the data structure documentation for each member";
+    //   }
+    //   else 
+    //   {
+    //      result+="the data types they belong to:";
+    //   }
+    //   return result;
+      if(!extractAll) {
+        return "ĵͳԱбеÿԱݽṹĵ";
+      } else {
+        return "ͳԱбеԱ͵:";
+      }
+
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     * annotated compound index (Fortran).
+     */
+    virtual QCString trCompoundIndexFortran()
+    // { return "Data Type Index"; }
+    { return ""; }
+
+
+    /*! This is used in LaTeX as the title of the chapter containing
+     *  the documentation of all data types (Fortran).
+     */
+    virtual QCString trTypeDocumentation()
+    // { return "Data Type Documentation"; }
+    { return "ĵ"; }
+
+    /*! This is used in the documentation of a file as a header before the 
+     *  list of (global) subprograms (Fortran).
+     */
+    virtual QCString trSubprograms()
+    //{ return "Functions/Subroutines"; }
+    { return "/"; }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for subprograms (Fortran)
+     */
+    virtual QCString trSubprogramDocumentation()
+    //{ return "Function/Subroutine Documentation"; }
+    { return "/ĵ"; }
+
+
+    /*! This is used in the documentation of a file/namespace/group before 
+     *  the list of links to documented compounds (Fortran)
+     */
+     virtual QCString trDataTypes()
+    // { return "Data Types"; }
+    { return ""; }
+    
+    /*! used as the title of page containing all the index of all modules (Fortran). */
+    virtual QCString trModulesList()
+    // { return "Modules List"; }
+    { return "ģб"; }
+
+    /*! used as an introduction to the modules list (Fortran) */
+    virtual QCString trModulesListDescription(bool extractAll)
+    {
+      // QCString result="Here is a list of all ";
+      // if (!extractAll) result+="documented ";
+      // result+="modules with brief descriptions:";
+      // return result;
+      if(!extractAll) {
+        return "Ҫĵģб:";
+      } else {
+        return "Ҫģб:";
+      }
+    }
+
+    /*! used as the title of the HTML page of a module/type (Fortran) */
+    virtual QCString trCompoundReferenceFortran(const char *clName,
+                                    ClassDef::CompoundType compType,
+                                    bool isTemplate)
+    {
+      // QCString result=(QCString)clName;
+      // switch(compType)
+      // {
+      //   case ClassDef::Class:      result+=" Module"; break;
+      //   case ClassDef::Struct:     result+=" Type"; break;
+      //   case ClassDef::Union:      result+=" Union"; break;
+      //   case ClassDef::Interface:  result+=" Interface"; break;
+      //   case ClassDef::Protocol:   result+=" Protocol"; break;
+      //   case ClassDef::Category:   result+=" Category"; break;
+      //   case ClassDef::Exception:  result+=" Exception"; break;
+      // }
+      // if (isTemplate) result+=" Template";
+      // result+=" Reference";
+      // return result;
+      QCString result=(QCString)clName;
+      switch(compType)
+      {
+        case ClassDef::Class:      result+=CN_SPC"ģ"; break;
+        case ClassDef::Struct:     result+=CN_SPC""; break;
+        case ClassDef::Union:      result+=CN_SPC""; break;
+        case ClassDef::Interface:  result+=CN_SPC""; break;
+        case ClassDef::Protocol:   result+=CN_SPC"ӿ"; break;
+        case ClassDef::Category:   result+=CN_SPC"Ŀ¼"; break;
+        case ClassDef::Exception:  result+=CN_SPC"쳣"; break;
+      }
+      if (isTemplate) result+="ģ";
+      result+="οֲ";
+      return result;
+    }
+    /*! used as the title of the HTML page of a module (Fortran) */
+    virtual QCString trModuleReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      // result+=" Module Reference";        
+      result += CN_SPC"ģοֲ";
+      return result;
+    }
+    
+    /*! This is put above each page as a link to all members of modules. (Fortran) */
+    virtual QCString trModulesMembers()
+    // { return "Module Members"; }
+    { return "ģԱ"; }
+
+    /*! This is an introduction to the page with all modules members (Fortran) */
+    virtual QCString trModulesMemberDescription(bool extractAll)
+    { 
+      // QCString result="Here is a list of all ";
+      // if (!extractAll) result+="documented ";
+      // result+="module members with links to ";
+      // if (extractAll) 
+      // {
+      //   result+="the module documentation for each member:";
+      // }
+      // else 
+      // {
+      //   result+="the modules they belong to:";
+      // }
+      // return result;
+      if(!extractAll) {
+        return "ĵģԱбеÿԱģĵ";
+      } else {
+        return "ģԱбеԱģ:";
+      }
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     *  index of all modules (Fortran).
+     */
+    virtual QCString trModulesIndex()
+    // { return "Modules Index"; }
+    { return "ģ"; }
+    
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trModule(bool, bool)
+    {       
+      // QCString result((first_capital ? "Module" : "module"));
+      // if (!singular)  result+="s";
+      // return result; 
+      return "ģ";
+    }
+    /*! This is put at the bottom of a module documentation page and is
+     *  followed by a list of files that were used to generate the page.
+     */
+    virtual QCString trGeneratedFromFilesFortran(ClassDef::CompoundType compType,
+        bool)
+    { // here s is one of " Module", " Struct" or " Union"
+      // single is true implies a single file
+      // QCString result=(QCString)"The documentation for this ";
+      // switch(compType)
+      // {
+      //   case ClassDef::Class:      result+="module"; break;
+      //   case ClassDef::Struct:     result+="type"; break;
+      //   case ClassDef::Union:      result+="union"; break;
+      //   case ClassDef::Interface:  result+="interface"; break;
+      //   case ClassDef::Protocol:   result+="protocol"; break;
+      //   case ClassDef::Category:   result+="category"; break;
+      //   case ClassDef::Exception:  result+="exception"; break;
+      // }
+      // result+=" was generated from the following file";
+      // if (single) result+=":"; else result+="s:";
+      // return result;
+      QCString result="";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+=CN_SPC"ģ"; break;
+        case ClassDef::Struct:     result+=CN_SPC""; break;
+        case ClassDef::Union:      result+=CN_SPC""; break;
+        case ClassDef::Interface:  result+=CN_SPC""; break;
+        case ClassDef::Protocol:   result+=CN_SPC"ӿ"; break;
+        case ClassDef::Category:   result+=CN_SPC"Ŀ¼"; break;
+        case ClassDef::Exception:  result+=CN_SPC"쳣"; break;
+      }
+      result+="ĵļ:";
+      return result;
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trType(bool, bool)
+    { 
+      return "";
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trSubprogram(bool, bool)
+    { 
+      return "ӳ";
+    }
+
+    /*! C# Type Constraint list */
+    virtual QCString trTypeConstraints()
+    {
+      return "";
+    }
 };
 
 #endif
