@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -100,7 +100,7 @@
 // Translator class (by the local maintainer) when the localized
 // translator is made up-to-date again.
 
-class TranslatorFrench : public Translator
+class TranslatorFrench : public TranslatorAdapter_1_5_4
 {
    public:
    
@@ -158,7 +158,7 @@ class TranslatorFrench : public Translator
     /*! header that is put before the list of typedefs. */
        virtual QCString trMemberTypedefDocumentation()
       { 
-         return "Documentation des dfinition de type membres"; }
+         return "Documentation des dfinitions de type membres"; }
     
     /*! header that is put before the list of enumerations. */
        virtual QCString trMemberEnumerationDocumentation()
@@ -998,7 +998,7 @@ class TranslatorFrench : public Translator
     /*! header that is put before the list of constructor/destructors. */
        virtual QCString trConstructorDocumentation()
       {
-         return "Documentation des contructeurs et destructeur"; 
+         return "Documentation des constructeurs et destructeur"; 
       }
     /*! Used in the file documentation to point to the corresponding sources. */
        virtual QCString trGotoSourceCode()
@@ -1184,7 +1184,7 @@ class TranslatorFrench : public Translator
             "class Inherited : public PublicBase,\n"
             "                  protected ProtectedBase,\n"
             "                  private PrivateBase,\n"
-            "                  public Undocumented\n"
+            "                  public Undocumented,\n"
             "                  public Templ<int>\n"
             "{\n"
             "  private:\n"
