@@ -3,7 +3,7 @@
  * $Id: xml.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -159,7 +159,7 @@ static void writeCombineScript()
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   t <<
   "<!-- XSLT script to combine the generated output into a single file. \n"
@@ -539,6 +539,7 @@ static void stripQualifiers(QCString &typeStr)
     if (typeStr.stripPrefix("static "));
     else if (typeStr.stripPrefix("virtual "));
     else if (typeStr.stripPrefix("volatile "));
+    else if (typeStr=="virtual") typeStr="";
     else done=TRUE;
   }
 }
@@ -563,6 +564,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   // enum values are written as part of the enum
   if (md->memberType()==MemberDef::EnumValue) return;
   if (md->isHidden()) return;
+  if (md->name().at(0)=='@') return; // anonymous member
 
   // group members are only visible in their group
   //if (def->definitionType()!=Definition::TypeGroup && md->getGroupDef()) return;
@@ -1012,31 +1014,34 @@ static void writeListOfAllMembers(ClassDef *cd,QTextStream &t)
       for (mii.toFirst();(mi=mii.current());++mii)
       {
         MemberDef *md=mi->memberDef;
-        Protection prot = mi->prot;
-        Specifier virt=md->virtualness();
-        t << "      <member refid=\"" << md->getOutputFileBase() << "_1" <<
-          md->anchor() << "\" prot=\"";
-        switch (prot)
+        if (md->name().at(0)!='@') // skip anonymous members
         {
-          case Public:    t << "public";    break;
-          case Protected: t << "protected"; break;
-          case Private:   t << "private";   break;
-          case Package:   t << "package";   break;
+          Protection prot = mi->prot;
+          Specifier virt=md->virtualness();
+          t << "      <member refid=\"" << md->getOutputFileBase() << "_1" <<
+            md->anchor() << "\" prot=\"";
+          switch (prot)
+          {
+            case Public:    t << "public";    break;
+            case Protected: t << "protected"; break;
+            case Private:   t << "private";   break;
+            case Package:   t << "package";   break;
+          }
+          t << "\" virt=\"";
+          switch(virt)
+          {
+            case Normal:  t << "non-virtual";  break;
+            case Virtual: t << "virtual";      break;
+            case Pure:    t << "pure-virtual"; break;
+          }
+          t << "\"";
+          if (!mi->ambiguityResolutionScope.isEmpty())
+          {
+            t << " ambiguityscope=\"" << convertToXML(mi->ambiguityResolutionScope) << "\"";
+          }
+          t << "><scope>" << convertToXML(cd->name()) << "</scope><name>" << 
+            convertToXML(md->name()) << "</name></member>" << endl;
         }
-        t << "\" virt=\"";
-        switch(virt)
-        {
-          case Normal:  t << "non-virtual";  break;
-          case Virtual: t << "virtual";      break;
-          case Pure:    t << "pure-virtual"; break;
-        }
-        t << "\"";
-        if (!mi->ambiguityResolutionScope.isEmpty())
-        {
-          t << " ambiguityscope=\"" << convertToXML(mi->ambiguityResolutionScope) << "\"";
-        }
-        t << "><scope>" << convertToXML(cd->name()) << "</scope><name>" << 
-          convertToXML(md->name()) << "</name></member>" << endl;
       }
     }
   }
@@ -1170,6 +1175,8 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   if (cd->name().find('@')!=-1) return; // skip anonymous compounds.
   if (cd->templateMaster()!=0)  return; // skip generated template instances.
 
+  msg("Generating XML output for class %s\n",cd->name().data());
+
   ti << "  <compound refid=\"" << cd->getOutputFileBase() 
      << "\" kind=\"" << cd->compoundTypeString()
      << "\"><name>" << convertToXML(cd->name()) << "</name>" << endl;
@@ -1183,7 +1190,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
@@ -1231,7 +1238,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
       {
         t << convertToXML(
               insertTemplateSpecifierInScope(
-              bcd->classDef->displayName(),bcd->templSpecifiers)
+              bcd->classDef->name(),bcd->templSpecifiers)
            );
       }
       else
@@ -1409,7 +1416,7 @@ static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
   
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
@@ -1496,7 +1503,7 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
@@ -1641,7 +1648,7 @@ static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
   }
 
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
     << gd->getOutputFileBase() << "\" kind=\"group\">" << endl;
@@ -1712,7 +1719,7 @@ static void generateXMLForDir(DirDef *dd,QTextStream &ti)
   }
 
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" 
     << dd->getOutputFileBase() << "\" kind=\"dir\">" << endl;
@@ -1765,7 +1772,7 @@ static void generateXMLForPage(PageDef *pd,QTextStream &ti,bool isExample)
   }
 
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
   writeXMLHeader(t);
   t << "  <compounddef id=\"" << pageName;
   t << "\" kind=\"" << kindName << "\">" << endl;
@@ -1873,7 +1880,7 @@ void generateXML()
     return;
   }
   QTextStream t(&f);
-  t.setEncoding(QTextStream::Latin1);
+  t.setEncoding(QTextStream::UnicodeUTF8);
 
   // write index header
   t << "<?xml version='1.0' encoding='UTF-8' standalone='no'?>" << endl;;
@@ -1886,7 +1893,6 @@ void generateXML()
     ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
     {
-      msg("Generating XML output for class %s\n",cd->name().data());
       generateXMLForClass(cd,t);
     }
   }
